summaryrefslogtreecommitdiffstats
path: root/libkdegames/kchatdialog.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kchatdialog.cpp')
-rw-r--r--libkdegames/kchatdialog.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/libkdegames/kchatdialog.cpp b/libkdegames/kchatdialog.cpp
index 58c90e69..7e0df7e8 100644
--- a/libkdegames/kchatdialog.cpp
+++ b/libkdegames/kchatdialog.cpp
@@ -55,17 +55,17 @@ class KChatDialogPrivate
KChatBase* mChat;
};
-KChatDialog::KChatDialog(KChatBase* chat, TQWidget* tqparent, bool modal)
-// : KDialogBase(Tabbed, i18n("Configure Chat"), Ok|Default|Apply|Cancel, Ok, tqparent, 0, modal, true)
- : KDialogBase(Plain, i18n("Configure Chat"), Ok|Default|Apply|Cancel, Ok, tqparent, 0, modal, true)
+KChatDialog::KChatDialog(KChatBase* chat, TQWidget* parent, bool modal)
+// : KDialogBase(Tabbed, i18n("Configure Chat"), Ok|Default|Apply|Cancel, Ok, parent, 0, modal, true)
+ : KDialogBase(Plain, i18n("Configure Chat"), Ok|Default|Apply|Cancel, Ok, parent, 0, modal, true)
{
init();
plugChatWidget(chat);
}
-KChatDialog::KChatDialog(TQWidget* tqparent, bool modal)
-// : KDialogBase(Tabbed, i18n("Configure Chat"), Ok|Default|Apply|Cancel, Ok, tqparent, 0, modal, true)
- : KDialogBase(Plain, i18n("Configure Chat"), Ok|Default|Apply|Cancel, Ok, tqparent, 0, modal, true)
+KChatDialog::KChatDialog(TQWidget* parent, bool modal)
+// : KDialogBase(Tabbed, i18n("Configure Chat"), Ok|Default|Apply|Cancel, Ok, parent, 0, modal, true)
+ : KDialogBase(Plain, i18n("Configure Chat"), Ok|Default|Apply|Cancel, Ok, parent, 0, modal, true)
{
init();
}